@@ -1,8 +1,9 @@
+from django.core.urlresolvers import reverse
 from django.test import TestCase
 from mock import patch, Mock
 
 from silk.config import SilkyConfig
-from silk.middleware import SilkyMiddleware
+from silk.middleware import SilkyMiddleware, _should_intercept
 from silk.models import Request
 
 
@@ -94,3 +95,29 @@ class TestApplyDynamicMappings(TestCase):
         ]
         middleware._apply_dynamic_mappings()  # Just checking no crash
 
+
+class TestShouldIntercept(TestCase):
+    def test_should_intercept_non_silk_request(self):
+        request = Request()
+        request.path = '/myapp/foo'
+        should_intercept = _should_intercept(request)
+
+        self.assertTrue(should_intercept)
+
+    def test_should_intercept_silk_request(self):
+        request = Request()
+        request.path = reverse('silk:summary')
+        should_intercept = _should_intercept(request)
+
+        self.assertFalse(should_intercept)
+
+    def test_should_intercept_ignore_paths(self):
+        SilkyConfig().SILKY_IGNORE_PATHS = [
+            '/ignorethis'
+        ]
+        request = Request()
+        request.path = '/ignorethis'
+        should_intercept = _should_intercept(request)
+
+        self.assertFalse(should_intercept)
+
